@@ -45,25 +45,25 @@
         <location filename="mainwindow.ui" line="215"/>
         <location filename="ui_mainwindow.h" line="561"/>
         <source>lz4</source>
-        <translation type="unfinished"/>
+        <translation>lz4</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="220"/>
         <location filename="ui_mainwindow.h" line="562"/>
         <source>lzo</source>
-        <translation type="unfinished"/>
+        <translation>lzo</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="225"/>
         <location filename="ui_mainwindow.h" line="563"/>
         <source>gzip</source>
-        <translation type="unfinished"/>
+        <translation>gzip</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="230"/>
         <location filename="ui_mainwindow.h" line="564"/>
         <source>xz</source>
-        <translation type="unfinished"/>
+        <translation>xz</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="238"/>
@@ -76,7 +76,7 @@
     <message>
         <location filename="mainwindow.ui" line="281"/>
         <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/local/share/excludes/iso-snapshot-exclude.list.</source>
-        <translation type="unfinished"/>
+        <translation>Também pode excluir certos diretórios selecionando as opções comuns abaixo, ou clicando no botão para editar diretamente /usr/local/share/excludes/iso-snapshot-exclude.list.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="338"/>
@@ -148,7 +148,7 @@
         <location filename="mainwindow.ui" line="461"/>
         <location filename="ui_mainwindow.h" line="582"/>
         <source>ISO compression scheme:</source>
-        <translation type="unfinished"/>
+        <translation>Esquema de compressão ISO:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="474"/>
@@ -309,18 +309,18 @@ removendo imagens anteriores e cópias guardadas:
     <message>
         <location filename="mainwindow.cpp" line="628"/>
         <source>MX Snapshot completed sucessfully!</source>
-        <translation type="unfinished"/>
+        <translation>MX Captura ISO completada com sucesso!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="629"/>
         <location filename="mainwindow.cpp" line="630"/>
         <source>Snapshot took %1 to finish.</source>
-        <translation type="unfinished"/>
+        <translation>O MX Captura ISO demorou %1 a terminar.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="631"/>
         <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
-        <translation type="unfinished"/>
+        <translation>Obrigado por usar o MX Captura ISO; execute de seguida o MX Criar USB-executável!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="644"/>
@@ -371,7 +371,7 @@ removendo imagens anteriores e cópias guardadas:
     <message>
         <location filename="mainwindow.cpp" line="803"/>
         <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
-        <translation type="unfinished"/>
+        <translation>O kernel atual não suporta o algoritmo de compressão selecionado, por favor edite o ficheiro de configuração e selecione um algoritmo diferente.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="807"/>
@@ -426,7 +426,7 @@ removendo imagens anteriores e cópias guardadas:
     <message>
         <location filename="mainwindow.cpp" line="942"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>Sobre o %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="943"/>
@@ -446,12 +446,12 @@ removendo imagens anteriores e cópias guardadas:
     <message>
         <location filename="mainwindow.cpp" line="947"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>Licença do %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="962"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>Ajuda do %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="970"/>
@@ -506,7 +506,7 @@ removendo imagens anteriores e cópias guardadas:
     <message>
         <location filename="main.cpp" line="76"/>
         <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
-        <translation type="unfinished"/>
+        <translation>O kernel atual não suporta Squashfs, não pode continuar.</translation>
     </message>
     <message>
         <location filename="main.cpp" line="87"/>
